package com.steerinfo.dil.controller;

import com.alibaba.fastjson.JSON;
import com.steerinfo.dil.feign.ESFeign;
import com.steerinfo.dil.service.impl.BmstrainDetailsOrderServiceImpl;
import com.steerinfo.dil.service.impl.BmstrainStatementServiceImpl;
import com.steerinfo.dil.util.BaseRESTfulController;
import com.steerinfo.dil.util.ColumnDataUtil;
import com.steerinfo.dil.util.PageListAdd;
import com.steerinfo.framework.controller.RESTfulResult;
import com.steerinfo.framework.service.pagehelper.PageHelper;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.math.BigDecimal;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @Description:
 * @Author:HuJianGuo
 * @GreateTime:2021/9/14 9:26
 * @Version:V2.0
 */
@RestController
@RequestMapping("/${api.version}/bmstrainstatement")
public class BmstrainStatementController extends BaseRESTfulController {

    @Autowired
    BmstrainStatementServiceImpl bmstrainStatementService;
    @Autowired
    ColumnDataUtil columnDataUtil;
    @Autowired
    ESFeign esFeign;

    /**
     * 展示火运账单列表
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @ApiModelProperty(value = "展示火运账单列表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "查询页数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "每页记录数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "apiId", value = "121", required = false, dataType = "BigDecimal")
    })
    @PostMapping("/getTrainStatementList")
    public RESTfulResult getTrainStatementList(@RequestBody(required = false) Map<String, Object> mapValue,
                                               Integer pageNum,
                                               Integer pageSize,
                                               Integer apiId,
                                               String con) {
        if (con != null) {
            if (!"undefined".equals(con)) {
                //设置要查询的索引名称
                String index = "get_train_statement_list";
                //获取查询结果
                return success(esFeign.getConResult(mapValue, index, apiId, pageNum, pageSize, con));
            }
        }
        //初始化过滤
        List<Map<String, Object>> trainStatementList = null;
        //如果有条件查询则跳过初始化，和创建索引
        if (mapValue.size() == 0) {
            //将查询结果存入索引中
            trainStatementList = bmstrainStatementService.getTrainStatementList(null);
            Map<String, Object> map = new HashMap<>();
            //添加索引
            map.put("index", "get_train_statement_list");
            //添加id
            map.put("indexId", "statementId");
            trainStatementList.add(map);
            //新建索引
            String s = JSON.toJSONString(trainStatementList);
            esFeign.insertIndex(trainStatementList);
            //删除
            trainStatementList.remove(trainStatementList.size() - 1);
        }
        if (trainStatementList == null) {
            trainStatementList = bmstrainStatementService.getTrainStatementList(mapValue);
        }
        PageHelper.startPage(pageNum, pageSize);
        //分页查询数据
        List<Map<String, Object>> columnList = bmstrainStatementService.getTrainStatementList(mapValue);
        PageListAdd data = columnDataUtil.tableColumnData(apiId, trainStatementList, columnList);
        return success(data);
    }

    /**
     * 生成火运费账单
     *
     * @param mapList
     * @return
     */
    @ApiModelProperty(value = "生成火运费账单")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapList", value = "详单列表", required = false, dataType = "java.util.List"),
    })
    @PostMapping("/addTrainStatement")
    public RESTfulResult addTrainStatement(@RequestBody List<Map<String, Object>> mapList) {
        int code1 = bmstrainStatementService.insertSelective(mapList);
        return success(code1);
    }

    /**
     * 展示账单下的详单
     *
     * @param batchId
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @param statementId
     * @return
     */
    @ApiOperation(value = "展示账单下的详单", notes = "分页查询")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "batchId", value = "批次id", required = false, dataType = "BigDecimal"),
            @ApiImplicitParam(name = "pageNum", value = "查询页数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "每页记录数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "apiId", value = "118", required = false, dataType = "BigDecimal"),
    })
    @PostMapping(value = "/getComplateTrainDetailsList")
    public RESTfulResult getComplateTrainDetailsList(BigDecimal batchId,
                                                     @RequestBody(required = false) Map<String, Object> mapValue,
                                                     Integer pageNum,
                                                     Integer pageSize,
                                                     Integer apiId,
                                                     BigDecimal statementId,
                                                     String con) {
        if (con != null) {
            if (!"undefined".equals(con)) {
                //设置要查询的索引名称
                String index = "get_uncomplate_train_details_list";
                //获取查询结果
                return success(esFeign.getConResult(mapValue, index, apiId, pageNum, pageSize, con));
            }
        }
        mapValue.put("batchId", batchId);
        mapValue.put("statementId", statementId);
        //初始化过滤
        List<Map<String, Object>> trainComplateDetailList = null;
        //如果有条件查询则跳过初始化，和创建索引
        if (mapValue.size() == 2) {
            //将查询结果存入索引中
            trainComplateDetailList = bmstrainStatementService.getComplateTrainDetailsList(mapValue);
            Map<String, Object> map = new HashMap<>();
            //添加索引
            map.put("index", "get_uncomplate_train_details_list");
            //添加id
            map.put("indexId", "detailsId");
            trainComplateDetailList.add(map);
            //新建索引
            String s = JSON.toJSONString(trainComplateDetailList);
            esFeign.insertIndex(trainComplateDetailList);
            //删除
            trainComplateDetailList.remove(trainComplateDetailList.size() - 1);
        }
        if (trainComplateDetailList == null) {
            trainComplateDetailList = bmstrainStatementService.getComplateTrainDetailsList(mapValue);
        }
        PageHelper.startPage(pageNum, pageSize);
        //分页查询数据
        List<Map<String, Object>> columnList = bmstrainStatementService.getComplateTrainDetailsList(mapValue);
        PageListAdd data = columnDataUtil.tableColumnData(apiId, trainComplateDetailList, columnList);
        return success(data);
    }

    /**
     * 展示火运实绩
     *
     * @param detailsId
     * @param mapVal
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @ApiOperation(value = "展示火运实绩", notes = "分页查询")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "detailsId", value = "详单id", required = false, dataType = "BigDecimal"),
            @ApiImplicitParam(name = "pageNum", value = "查询页数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "每页记录数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "apiId", value = "122", required = false, dataType = "BigDecimal"),
    })
    @PostMapping(value = "/getStatementTrainResultList")
    public RESTfulResult getStatementTrainResultList(@RequestBody(required = false) Map<String, Object> mapVal,
                                                     Integer pageNum,
                                                     Integer pageSize,
                                                     Integer apiId,
                                                     Integer detailsId) {
        if (mapVal == null) {
            mapVal = new HashMap<>();
        }
        mapVal.put("detailsId", detailsId);
        List<Map<String, Object>> list = bmstrainStatementService.getTrainResultList(mapVal);
        PageHelper.startPage(pageNum, pageSize);
        //分页查询数据
        List<Map<String, Object>> columnList = bmstrainStatementService.getTrainResultList(mapVal);
        PageListAdd data = columnDataUtil.tableColumnData(apiId, list, columnList);
        return success(data);
    }
}
