package com.steerinfo.dil.service.impl;

import com.steerinfo.dil.feign.JoinApiFeign;
import com.steerinfo.dil.mapper.BmstrainStatementMapper;
import com.steerinfo.dil.model.BmstrainDetailsOrder;
import com.steerinfo.dil.model.BmstrainDetailsStatement;
import com.steerinfo.dil.model.BmstrainStatement;
import com.steerinfo.dil.service.IBmstrainStatementService;
import com.steerinfo.dil.util.EASUtil;
import com.steerinfo.dil.util.NoUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.math.BigDecimal;
import java.text.DecimalFormat;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @Description:
 * @Author:HuJianGuo
 * @GreateTime:2021/9/14 11:23
 * @Version:V2.0
 */
@Service
public class BmstrainStatementServiceImpl implements IBmstrainStatementService {

    @Autowired
    BmstrainStatementMapper bmstrainStatementMapper;
    @Autowired
    BmstrainDetailsOrderServiceImpl bmstrainDetailsOrderService;
    @Autowired
    BmstrainDetailsStatementServiceImpl bmstrainDetailsStatementService;
    @Autowired
    NoUtil noUtil;
    @Autowired
    JoinApiFeign joinApiFeign;
    @Autowired
    EASUtil easUtil;

    /**
     * 查询最大id
     *
     * @return
     */
    @Override
    public BigDecimal selectMaxId() {
        return bmstrainStatementMapper.selectStatementId();
    }

    /**
     * 展示账单列表
     *
     * @param mapValue
     * @return
     */
    @Override
    public List<Map<String, Object>> getTrainStatementList(Map<String, Object> mapValue) {
        List<Map<String, Object>> listMap = bmstrainStatementMapper.getTrainStatementList(mapValue);
        // 将下浮后金额及保证金存入进map
        for (Map<String, Object> map : listMap) {
            BigDecimal statementTotalAmount = (BigDecimal) map.get("statementTotalAmount");
            Double floatAmount = statementTotalAmount.doubleValue() * 0.8;
            Double maginAmount = statementTotalAmount.doubleValue() * 0.2;
            DecimalFormat df = new DecimalFormat("0.00");
            String statementFloatAmount = df.format(floatAmount);
            String statementMaginAmount = df.format(maginAmount);
            map.put("statementFloatAmount", statementFloatAmount);
            map.put("statementMaginAmount", statementMaginAmount);
        }
        return listMap;
    }

    /**
     * 生成账单
     *
     * @param mapLists
     * @return
     */
    @Transactional
    @Override
    public int insertSelective(List<Map<String, Object>> mapLists) {
        BmstrainStatement bmstrainStatement = new BmstrainStatement();
        // 设置主键
        BigDecimal statementId = selectMaxId();
        bmstrainStatement.setStatementId(statementId);
        // 设置账单编号
        String statementNo = noUtil.setResultNo("HYZD", statementId);
        bmstrainStatement.setStatementNo(statementNo);
        bmstrainStatement.setStatementShipperId(new BigDecimal(1));
        Double totalAmount = new Double(0);
        for (int i = 0; i < mapLists.size(); i++) {
            Map<String, Object> map = mapLists.get(i);
            Double detailsAmount = (Double) map.get("detailsAmount");
            totalAmount += detailsAmount;
            // 新增关系
            BmstrainDetailsStatement bmstrainDetailsStatement = new BmstrainDetailsStatement();
            bmstrainDetailsStatement.setDetailsStatementId(bmstrainDetailsStatementService.selectMaxId());
            BigDecimal detailsId = new BigDecimal((Integer) map.get("detailsId"));
            bmstrainDetailsStatement.setDetailsId(detailsId);
            BmstrainDetailsOrder bmstrainDetailsOrder = bmstrainDetailsOrderService.selectByPrimaryKey(detailsId);
            bmstrainDetailsOrder.setWetherToStatement(new BigDecimal(1));
            bmstrainDetailsStatement.setStatementId(statementId);
            // 设置常规字段
            bmstrainDetailsStatement.setInsertTime(new Date());
            bmstrainDetailsStatement.setInsertUsername("admin");
            bmstrainDetailsStatement.setUpdateTime(new Date());
            bmstrainDetailsStatement.setUpdateUsername("admin");
            bmstrainDetailsStatement.setInsertUpdateRemark("无");
            bmstrainDetailsOrderService.updateByPrimaryKeySelective(bmstrainDetailsOrder);
            bmstrainDetailsStatementService.insertSelective(bmstrainDetailsStatement);
        }
        bmstrainStatement.setStatementDate(new Date());
        DecimalFormat df = new DecimalFormat("0.00");
        String statementFloatAmount = df.format(totalAmount);
        bmstrainStatement.setStatementTotalAmount(new BigDecimal(statementFloatAmount));
        bmstrainStatement.setInsertTime(new Date());
        bmstrainStatement.setInsertUsername("admin");
        bmstrainStatement.setUpdateTime(new Date());
        bmstrainStatement.setUpdateUsername("admin");
        bmstrainStatement.setInsertUpdateRemark("无");
        int code = bmstrainStatementMapper.insertSelective(bmstrainStatement);
        // 调用金蝶接口
        List<Map<String, Object>> entries = joinApiFeign.getPurchaseTrainDetailsOrder(statementId.intValue());
        Map<String, Object> head = joinApiFeign.getTrainStatement(statementId.intValue());
        Map<String,Object> input = new HashMap<>();
        input.put("entries", entries);
        input.put("head", head);
        Map<String, Object> totalMap = easUtil.getTotalMap();
        totalMap.put("input",input);
        joinApiFeign.WSFaceWay(totalMap);
        return code;
    }

    /**
     * 展示账单中的详单
     *
     * @param mapValue
     * @return
     */
    @Override
    public List<Map<String, Object>> getComplateTrainDetailsList(Map<String, Object> mapValue) {
        return bmstrainStatementMapper.getComplateTrainDetailsList(mapValue);
    }

    /**
     * 展示火运实绩
     *
     * @param mapValue
     * @return
     */
    @Override
    public List<Map<String, Object>> getTrainResultList(Map<String, Object> mapValue) {
        return bmstrainStatementMapper.getTrainResultList(mapValue);
    }
}
